@@ -12,6 +12,7 @@ class aib_logger:
         CREATE="Create"
         UPDATE="Update"
         DELETE="Delete"
+        UPLOAD="UPLOAD"
         OTHER="Other"
     
     class Severities(Enum):
@@ -32,7 +33,8 @@ class aib_logger:
         category:Categories=Categories.OTHER,
         action:Actions=Actions.OTHER,
         severity:Severities=Severities.INFO,
-        extra_labels:list=[]
+        extra_labels:list=[],
+        object:dict={}
            ):
         import inspect
         payload={
@@ -42,7 +44,8 @@ class aib_logger:
             "category":category.value,
             "action":action.value,
             "extra_labels":extra_labels,
-            "message":msg
+            "message":msg,
+            "object":object
         }
         # Send the Log request
         self.logger.log_struct(payload, severity=severity.value)
\ No newline at end of file
